@@ -125,10 +125,11 @@ void AvatarButton::createAvatarMenu()
         userIsAuthor = true; // The post or comment is ours
     }
 
-    this->avatarMenu = new QMenu();
+    this->avatarMenu = new QMenu(this);
     avatarMenu->setSeparatorsCollapsible(false);
 
-    this->avatarMenuIdAction = new QAction(QIcon::fromTheme("user-identity"),
+    this->avatarMenuIdAction = new QAction(QIcon::fromTheme("user-identity",
+                                                            QIcon(":/images/no-avatar.png")),
                                            this->authorId, this);
     avatarMenuIdAction->setSeparator(true); // Make it nicer and not clickable
     avatarMenu->addAction(avatarMenuIdAction);
