@@ -157,7 +157,7 @@ Comment::Comment(PumpController *pumpController,
     deleteLabel->setContextMenuPolicy(Qt::NoContextMenu);
     deleteLabel->setAlignment(Qt::AlignTop | Qt::AlignRight);
     deleteLabel->setFont(commentsFont);
-    deleteLabel->setToolTip(tr("Delete this comment"));
+    deleteLabel->setToolTip(tr("Erase this comment"));
     connect(deleteLabel, SIGNAL(linkActivated(QString)),
             this, SLOT(deleteComment()));
 
@@ -179,6 +179,8 @@ Comment::Comment(PumpController *pumpController,
     contentLabel->setAlignment(Qt::AlignLeft);
     contentLabel->setFont(commentsFont);
     contentLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
+    // To help screen readers add Qt::TextSelectableByKeyboard flag too;
+    // Not adding for now, because it doesn't really help much. This will work better with Qt5
     contentLabel->setWordWrap(true);
     contentLabel->setOpenExternalLinks(true);
     contentLabel->setTextFormat(Qt::RichText);
