@@ -46,7 +46,7 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     sizePolicy.setHeightForWidth(false);
     sizePolicy.setWidthForHeight(false);
     sizePolicy.setHorizontalPolicy(QSizePolicy::Minimum);
-    sizePolicy.setVerticalPolicy(QSizePolicy::Maximum);
+    sizePolicy.setVerticalPolicy(QSizePolicy::Minimum);
     commentsWidget->setSizePolicy(sizePolicy);
     commentsWidget->setLayout(commentsLayout);
 
@@ -58,6 +58,10 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     commentsScrollArea->setWidget(commentsWidget);
     commentsScrollArea->setWidgetResizable(true);
 
+    this->getAllCommentsTimer = new QTimer(this);
+    getAllCommentsTimer->setSingleShot(true);
+    connect(getAllCommentsTimer, SIGNAL(timeout()),
+            this, SLOT(requestAllComments()));
 
     // Hide these until setComments() is called, if there are any comments
     showAllCommentsLinkLabel->hide();
@@ -97,7 +101,8 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
     this->commentButton = new QPushButton(QIcon::fromTheme("mail-send",
                                                            QIcon(":/images/button-post.png")),
-                                          tr("Comment"));
+                                          tr("Comment",
+                                             "Infinitive verb"));
     commentButton->setToolTip(tr("You can press Control+Enter to send "
                                  "the comment with the keyboard") + "<b></b>");
     connect(commentButton, SIGNAL(clicked()),
@@ -112,17 +117,21 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
             commentComposer, SLOT(cancelPost()));
 
 
-    mainLayout = new QGridLayout();
-    mainLayout->setContentsMargins(0, 0, 0, 0);
-    mainLayout->addWidget(showAllCommentsLinkLabel, 0, 0, 1, 4, Qt::AlignRight | Qt::AlignTop);
-    mainLayout->addWidget(commentsScrollArea,       1, 0, 1, 4);
-    mainLayout->addWidget(commentComposer,          2, 0, 4, 3);
-    mainLayout->addWidget(toolsButton,              2, 3, 1, 1);
-    mainLayout->addWidget(statusInfoLabel,          3, 3, 1, 1, Qt::AlignCenter);
-    mainLayout->addWidget(commentButton,            4, 3, 1, 1);
-    mainLayout->addWidget(cancelButton,             5, 3, 1, 1);
-    this->setLayout(mainLayout);
+    bottomLayout = new QGridLayout();
+    bottomLayout->setContentsMargins(0, 0, 0, 0);
+    bottomLayout->addWidget(commentComposer,        0, 0, 4, 3);
+    bottomLayout->addWidget(toolsButton,            0, 3, 1, 1);
+    bottomLayout->addWidget(statusInfoLabel,        1, 3, 1, 1, Qt::AlignCenter);
+    bottomLayout->addWidget(commentButton,          2, 3, 1, 1);
+    bottomLayout->addWidget(cancelButton,           3, 3, 1, 1);
 
+    mainLayout = new QVBoxLayout();
+    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->addWidget(showAllCommentsLinkLabel, 0, Qt::AlignRight | Qt::AlignTop);
+    mainLayout->addWidget(commentsScrollArea,       3);
+    mainLayout->addLayout(bottomLayout,             0);
+
+    this->setLayout(mainLayout);
 
     this->setMinimumMode();
 
@@ -327,7 +336,7 @@ void CommenterBlock::onPostingCommentOk()
                this, SLOT(onPostingCommentFailed()));
 
 
-    this->requestAllComments(); // FIXME: request comments after a delay
+    this->getAllCommentsTimer->start(2000); // Request comments after a delay
 }
 
 
