@@ -22,6 +22,7 @@
 #define COMMENTER_H
 
 #include <QWidget>
+#include <QVBoxLayout>
 #include <QGridLayout>
 #include <QScrollArea>
 #include <QPushButton>
@@ -76,7 +77,8 @@ protected:
     virtual void resizeEvent(QResizeEvent *event);
 
 private:
-    QGridLayout *mainLayout;
+    QVBoxLayout *mainLayout;
+    QGridLayout *bottomLayout;
 
     QScrollArea *commentsScrollArea;
     QWidget *commentsWidget;
@@ -85,6 +87,7 @@ private:
 
 
     QLabel *showAllCommentsLinkLabel;
+    QTimer *getAllCommentsTimer; // To get all comments after a delay
 
     Composer *commentComposer;
     QPushButton *toolsButton;
