@@ -47,9 +47,12 @@ Composer::Composer(bool forPublisher)
     symbolsMenu->addAction(QString::fromUtf8("\342\231\253")); // Musical note
     symbolsMenu->addAction(QString::fromUtf8("\342\230\225")); // Coffee
     symbolsMenu->addAction(QString::fromUtf8("\342\234\224")); // Check mark
+    symbolsMenu->addAction(QString::fromUtf8("\342\234\230")); // Ballot X
     symbolsMenu->addAction(QString::fromUtf8("\342\230\205")); // Black star
     symbolsMenu->addAction(QString::fromUtf8("\342\254\205")); // Arrow to the left
     symbolsMenu->addAction(QString::fromUtf8("\342\236\241")); // Arrow to the right
+    symbolsMenu->addAction(QString::fromUtf8("\342\231\273")); // Recycling symbol
+    symbolsMenu->addAction(QString::fromUtf8("\342\210\236")); // Infinity
     connect(symbolsMenu, SIGNAL(triggered(QAction*)),
             this, SLOT(insertSymbol(QAction*)));
 
@@ -86,6 +89,10 @@ Composer::Composer(bool forPublisher)
                          this,
                          SLOT(makeHeader()),
                          QKeySequence("Ctrl+H"));
+    toolsMenu->addAction(QIcon::fromTheme("format-list-unordered"),
+                         tr("List"),
+                         this,
+                         SLOT(makeList()));
     toolsMenu->addAction(QIcon::fromTheme("format-justify-fill"),
                          tr("Preformatted block"),
                          this,
@@ -182,8 +189,7 @@ void Composer::insertLink(QString url, QString title)
     }
 
     this->insertHtml("<a href=\"" + url + "\">"
-                     "<span style=\"color:#0088CC\">"
-                     + title + "</span></a> "); // Important, space after!
+                     + title + "</a> "); // Important, space after!
 }
 
 int Composer::getMessageLabelHeight()
@@ -234,6 +240,11 @@ void Composer::keyPressEvent(QKeyEvent *event)
             this->cancelPost();
         }
     }
+    else if (event->key() == Qt::Key_Up && this->textCursor().atStart())
+    {
+        qDebug() << "KEYPRESS: atStart(); will focus on TITLE field";
+        emit focusTitleRequested();
+    }
     else
     {
         QTextEdit::keyPressEvent(event);
@@ -401,6 +412,20 @@ void Composer::makeHeader()
 }
 
 
+void Composer::makeList()
+{
+    QString selectedText = this->textCursor().selectedText();
+
+    if (!selectedText.isEmpty())
+    {
+        this->textCursor().removeSelectedText();
+        this->insertHtml("<ul><li>" + selectedText + "</li></ul><br>");
+    }
+
+    this->setFocus();
+}
+
+
 
 /*
  * Put selected text into a <pre> block
