@@ -52,6 +52,7 @@ signals:
     void focusReceived();
     void editingFinished();
     void editingCancelled();
+    void focusTitleRequested();
 
 public slots:
     void makeNormal();
@@ -60,6 +61,7 @@ public slots:
     void makeUnderline();
     void makeStrikethrough();
     void makeHeader();
+    void makeList();
     void makePreformatted();
     void makeQuote();
     void makeLink();
