@@ -41,6 +41,7 @@
 
 #include "colorpicker.h"
 #include "notifications.h"
+#include "proxydialog.h"
 
 
 class ConfigDialog : public QWidget
@@ -86,6 +87,9 @@ private:
     QCheckBox *tabsMovableCheckbox;
     QCheckBox *publicPostsCheckbox;
 
+    QPushButton *proxyConfigButton;
+
+    ProxyDialog *proxyDialog;
 
     // Tab 2, color options
     QWidget *colorOptionsWidget;
@@ -96,6 +100,7 @@ private:
     ColorPicker *colorPicker3;
     ColorPicker *colorPicker4;
     ColorPicker *colorPicker5;
+    ColorPicker *colorPicker6;
 
 
     // Tab 3, notification options
