@@ -42,37 +42,15 @@ ContactCard::ContactCard(PumpController *pumpController,
     // Get local file name, which is stored in base64 hash form
     QString avatarFilename = MiscHelpers::getCachedAvatarFilename(contactAvatarUrl);
 
-    bool validAvatar = false;
-    QFile avatarFile(avatarFilename);
-    if (avatarFile.exists(avatarFilename) && !contactAvatarUrl.isEmpty())
+    // Load avatar if already cached
+    bool validAvatar = this->setAvatar(avatarFilename);
+    if (!validAvatar && !contactAvatarUrl.isEmpty())
     {
-        // Load avatar if already cached
-        QPixmap avatarPixmap = QPixmap(avatarFilename).scaled(64, 64,
-                                                              Qt::KeepAspectRatio,
-                                                              Qt::SmoothTransformation);
-        if (!avatarPixmap.isNull())
-        {
-            avatarLabel->setPixmap(avatarPixmap);
-            validAvatar = true;
-            qDebug() << "ContactCard: Using cached avatar";
-        }
-    }
+        connect(pController, SIGNAL(avatarStored(QString,QString)),
+                this, SLOT(redrawAvatar(QString,QString)));
 
-    if (!validAvatar)
-    {
-        // Placeholder image
-        avatarLabel->setPixmap(QIcon::fromTheme("user-identity",
-                                                QIcon(":/images/no-avatar.png")).pixmap(64, 64));
-        qDebug() << "ContactCard: Using placeholder, downloading avatar";
-
-        if (!contactAvatarUrl.isEmpty())
-        {
-            connect(pController, SIGNAL(avatarStored(QString,QString)),
-                    this, SLOT(redrawAvatar(QString,QString)));
-
-            // Download avatar for next time
-            pController->enqueueAvatarForDownload(contactAvatarUrl);
-        }
+        // Download avatar for next time
+        pController->enqueueAvatarForDownload(contactAvatarUrl);
     }
 
 
@@ -173,7 +151,8 @@ ContactCard::ContactCard(PumpController *pumpController,
     //optionsMenu->addMenu(addToListMenu); // Don't include it for now, until 1.3 /FIXME
 
 
-    optionsButton = new QPushButton(QIcon::fromTheme("user-properties"),
+    optionsButton = new QPushButton(QIcon::fromTheme("user-properties",
+                                                     QIcon(":/images/no-avatar.png")),
                                     tr("User Options"));
     optionsButton->setFlat(true);
     optionsButton->setMenu(optionsMenu);
@@ -226,6 +205,32 @@ void ContactCard::setButtonToUnfollow()
 }
 
 
+bool ContactCard::setAvatar(QString avatarFilename)
+{
+    bool validAvatar = false;
+
+    QPixmap avatarPixmap = QPixmap(avatarFilename)
+                           .scaledToWidth(64, Qt::SmoothTransformation);
+    if (!avatarPixmap.isNull())
+    {
+        avatarLabel->setPixmap(avatarPixmap);
+        validAvatar = true;
+        qDebug() << "ContactCard: Using cached avatar";
+    }
+
+
+    if (!validAvatar)
+    {
+        // Placeholder image
+        avatarLabel->setPixmap(QIcon::fromTheme("user-identity",
+                                                QIcon(":/images/no-avatar.png")).pixmap(64, 64));
+        qDebug() << "ContactCard: Using placeholder";
+    }
+
+    return validAvatar;
+}
+
+
 QString ContactCard::getNameAndIdString()
 {
     return QString("%1 <%2>").arg(contactName).arg(contactId);
@@ -284,8 +289,6 @@ void ContactCard::redrawAvatar(QString avatarUrl, QString avatarFilename)
         disconnect(pController, SIGNAL(avatarStored(QString,QString)),
                    this, SLOT(redrawAvatar(QString,QString)));
 
-        avatarLabel->setPixmap(QPixmap(avatarFilename).scaled(48, 48,
-                                                              Qt::KeepAspectRatio,
-                                                              Qt::SmoothTransformation));
+        this->setAvatar(avatarFilename);
     }
 }
