@@ -94,11 +94,13 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     // Options menu
     optionsMenu = new QMenu("*options-menu*");
-    optionsMenu->addAction(QIcon::fromTheme("view-refresh"),
+    optionsMenu->addAction(QIcon::fromTheme("view-refresh",
+                                            QIcon(":/images/menu-refresh.png")),
                            tr("Reload Followers"),
                            this,
                            SLOT(refreshFollowers()));
-    optionsMenu->addAction(QIcon::fromTheme("view-refresh"),
+    optionsMenu->addAction(QIcon::fromTheme("view-refresh",
+                                            QIcon(":/images/menu-refresh.png")),
                            tr("Reload Following"),
                            this,
                            SLOT(refreshFollowing()));
@@ -112,7 +114,8 @@ ContactManager::ContactManager(PumpController *pumpController,
                            this,
                            SLOT(exportFollowing()));
     optionsMenu->addSeparator();
-    optionsMenu->addAction(QIcon::fromTheme("view-refresh"),
+    optionsMenu->addAction(QIcon::fromTheme("view-refresh",
+                                            QIcon(":/images/menu-refresh.png")),
                            tr("Reload Lists"),
                            this,
                            SLOT(refreshPersonLists()));
