@@ -53,7 +53,8 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
 
 
     actionTypeComboBox = new QComboBox();
-    actionTypeComboBox->addItem(QIcon::fromTheme("edit-delete"),
+    actionTypeComboBox->addItem(QIcon::fromTheme("edit-delete",
+                                                 QIcon(":/images/button-delete.png")),
                                 tr("Hide"));
     actionTypeComboBox->addItem(QIcon::fromTheme("format-fill-color"),
                                 tr("Highlight"));
@@ -61,7 +62,8 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     filterTypeComboBox = new QComboBox();
     filterTypeComboBox->addItem(QIcon::fromTheme("accessories-text-editor"),
                                 tr("Post Contents"));
-    filterTypeComboBox->addItem(QIcon::fromTheme("user-identity"),
+    filterTypeComboBox->addItem(QIcon::fromTheme("user-identity",
+                                                 QIcon(":/images/no-avatar.png")),
                                 tr("Author ID"));
     filterTypeComboBox->addItem(QIcon::fromTheme("applications-other"),
                                 tr("Application"));
@@ -71,7 +73,8 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     filterWordsLineEdit = new QLineEdit();
     filterWordsLineEdit->setPlaceholderText(tr("Keywords..."));
 
-    addFilterButton = new QPushButton(QIcon::fromTheme("list-add"),
+    addFilterButton = new QPushButton(QIcon::fromTheme("list-add",
+                                                       QIcon(":/images/list-add.png")),
                                       tr("&Add Filter"));
     connect(addFilterButton, SIGNAL(clicked()),
             this, SLOT(addFilter()));
@@ -80,18 +83,21 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     currentFiltersListWidget = new QListWidget();
     currentFiltersListWidget->setToolTip(tr("Filters in use"));
 
-    removeFilterButton = new QPushButton(QIcon::fromTheme("list-remove"),
+    removeFilterButton = new QPushButton(QIcon::fromTheme("list-remove",
+                                                          QIcon(":/images/list-remove.png")),
                                          tr("&Remove Selected Filter"));
     connect(removeFilterButton, SIGNAL(clicked()),
             this, SLOT(removeFilter()));
 
 
-    saveButton = new QPushButton(QIcon::fromTheme("document-save"),
+    saveButton = new QPushButton(QIcon::fromTheme("document-save",
+                                                  QIcon(":/images/button-save.png")),
                                tr("&Save Filters"));
     connect(saveButton, SIGNAL(clicked()),
             this, SLOT(saveFilters()));
 
-    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel"),
+    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
+                                                    QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"));
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(hide()));
