@@ -196,7 +196,8 @@ QTreeWidgetItem *ListsManager::createPersonItem(QString id, QString name,
     QPixmap avatarPixmap = QPixmap(avatarFile);
     if (avatarPixmap.isNull())
     {
-        personItem->setIcon(0, QIcon::fromTheme("user-identity"));
+        personItem->setIcon(0, QIcon::fromTheme("user-identity",
+                                                QIcon(":/images/no-avatar.png")));
     }
     else
     {
