@@ -53,8 +53,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     // Filter checker
     filterChecker = new FilterChecker(this);
 
-    ////// GUI
 
+    ////// GUI
 
     // User's profile editor, in its own window
     profileEditor = new ProfileEditor(pumpController, this);
@@ -73,9 +73,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
     // Left side
-    leftTopLayout = new QHBoxLayout();
-    leftTopLayout->setAlignment(Qt::AlignLeft);
-
     avatarIconButton = new QPushButton();
     avatarIconButton->setIcon(QIcon(QPixmap(":/images/no-avatar.png")
                                     .scaled(64, 64,
@@ -87,7 +84,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     avatarIconButton->setIconSize(QSize(64, 64));
     connect(avatarIconButton, SIGNAL(clicked()),
             profileEditor, SLOT(show()));
-    leftTopLayout->addWidget(avatarIconButton, 0, Qt::AlignLeft);
 
 
     fullNameLabel = new QLabel("[-------------]");
@@ -115,7 +111,10 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     userInfoLayout->addWidget(fullNameLabel);
     userInfoLayout->addWidget(userIdLabel);
     userInfoLayout->addWidget(userHometownLabel);
-    leftTopLayout->addLayout(userInfoLayout);
+
+    leftTopLayout = new QHBoxLayout();
+    leftTopLayout->addWidget(avatarIconButton, 0, Qt::AlignLeft);
+    leftTopLayout->addLayout(userInfoLayout,   1);
 
 
     leftPanel = new QToolBox(); // For now, only one "section"...
@@ -134,7 +133,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     leftSideWidget = new QWidget();
     leftLayout = new QVBoxLayout();
     leftLayout->setContentsMargins(0, 0, 0, 0);
-    leftLayout->addSpacing(2);
     leftLayout->addLayout(leftTopLayout);       // Avatar + user info
     leftLayout->addSpacing(2);
     leftLayout->addWidget(leftPanel);           // Meanwhile feed
@@ -349,7 +347,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
             this, SLOT(adjustTimelineSizes()));
 
 
-
     ////////////////// Load configuration from disk
     loadSettings();
 
@@ -391,6 +388,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(pumpController, SIGNAL(logMessage(QString,QString)),
             logViewer, SLOT(addToLog(QString,QString)));
 
+    // Help widget; "Getting started", etc.
+    helpWidget = new HelpWidget(this);
+
 
     ///
     //////////////////////////////// Connections for PumpController //////////
@@ -406,7 +406,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     connect(pumpController, SIGNAL(authorizationStatusChanged(bool)),
             this, SLOT(toggleWidgetsByAuthorization(bool)));
-
+    connect(pumpController, SIGNAL(authorizationFailed(QString,QString)),
+            this, SLOT(showAuthError(QString,QString)));
 
 
     // After receiving timeline contents, update corresponding timeline
@@ -457,8 +458,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
     // After receiving the minor feed ("Meanwhile"), update it
-    connect(pumpController, SIGNAL(minorFeedReceived(QVariantList)),
-            meanwhileFeed, SLOT(setFeedContents(QVariantList)));
+    connect(pumpController, SIGNAL(minorFeedReceived(QVariantList,QString,QString)),
+            meanwhileFeed, SLOT(setFeedContents(QVariantList,QString,QString)));
 
 
     // Show notifications for events sent from pumpController
@@ -510,8 +511,13 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
         this->setStatusBarMessage(tr("Your account is not configured yet."));
     }
 
-    this->adjustTimelineSizes();
-    qApp->processEvents();
+    // Post-init timer
+    postInitTimer = new QTimer(this);
+    postInitTimer->setSingleShot(true);
+    connect(postInitTimer, SIGNAL(timeout()),
+            this, SLOT(postInit()));
+    postInitTimer->start(1000);
+
 
     logViewer->addToLog(tr("Dianara started."));
 
@@ -622,7 +628,8 @@ void MainWindow::createMenus()
 {
     sessionMenu = new QMenu(tr("&Session"));
 
-    sessionUpdateMainTimeline = new QAction(QIcon::fromTheme("view-refresh"),
+    sessionUpdateMainTimeline = new QAction(QIcon::fromTheme("view-refresh",
+                                                             QIcon(":/images/menu-refresh.png")),
                                             tr("&Update Timeline"),
                                             this);
     sessionUpdateMainTimeline->setShortcut(QKeySequence(Qt::Key_F5));
@@ -631,7 +638,8 @@ void MainWindow::createMenus()
             mainTimeline, SLOT(goToFirstPage()));
     sessionMenu->addAction(sessionUpdateMainTimeline);
 
-    sessionUpdateDirectTimeline = new QAction(QIcon::fromTheme("view-refresh"),
+    sessionUpdateDirectTimeline = new QAction(QIcon::fromTheme("view-refresh",
+                                                               QIcon(":/images/menu-refresh.png")),
                                               tr("Update &Messages"),
                                               this);
     sessionUpdateDirectTimeline->setShortcut(QKeySequence(Qt::Key_F6));
@@ -640,7 +648,8 @@ void MainWindow::createMenus()
             directTimeline, SLOT(goToFirstPage()));
     sessionMenu->addAction(sessionUpdateDirectTimeline);
 
-    sessionUpdateActivityTimeline = new QAction(QIcon::fromTheme("view-refresh"),
+    sessionUpdateActivityTimeline = new QAction(QIcon::fromTheme("view-refresh",
+                                                                 QIcon(":/images/menu-refresh.png")),
                                                 tr("Update &Activity"),
                                                 this);
     sessionUpdateActivityTimeline->setShortcut(QKeySequence(Qt::Key_F7));
@@ -650,7 +659,8 @@ void MainWindow::createMenus()
     sessionMenu->addAction(sessionUpdateActivityTimeline);
 
 
-    sessionUpdateFavoritesTimeline = new QAction(QIcon::fromTheme("view-refresh"),
+    sessionUpdateFavoritesTimeline = new QAction(QIcon::fromTheme("view-refresh",
+                                                                  QIcon(":/images/menu-refresh.png")),
                                                  tr("Update Fa&vorites"),
                                                  this);
     sessionUpdateFavoritesTimeline->setShortcut(QKeySequence(Qt::Key_F8));
@@ -660,7 +670,8 @@ void MainWindow::createMenus()
     sessionMenu->addAction(sessionUpdateFavoritesTimeline);
 
 
-    sessionUpdateMinorFeed = new QAction(QIcon::fromTheme("view-refresh"),
+    sessionUpdateMinorFeed = new QAction(QIcon::fromTheme("view-refresh",
+                                                          QIcon(":/images/menu-refresh.png")),
                                          tr("Update Minor &Feed"),
                                          this);
     sessionUpdateMinorFeed->setShortcut(QKeySequence(Qt::Key_F10));
@@ -670,10 +681,10 @@ void MainWindow::createMenus()
     sessionMenu->addAction(sessionUpdateMinorFeed);
 
 
-    sessionUpdateAllTimelines = new QAction(QIcon::fromTheme("view-refresh"),
+    sessionUpdateAllTimelines = new QAction(QIcon::fromTheme("view-refresh",
+                                                             QIcon(":/images/menu-refresh.png")),
                                          tr("Update All Timelines"),
                                          this);
-    sessionUpdateAllTimelines->setShortcut(QKeySequence("Ctrl+F5"));
     sessionUpdateAllTimelines->setDisabled(true);
     connect(sessionUpdateAllTimelines, SIGNAL(triggered()),
             this, SLOT(updateAllTimelines()));
@@ -691,7 +702,8 @@ void MainWindow::createMenus()
 
     sessionMenu->addSeparator();
 
-    sessionPostNote = new QAction(QIcon::fromTheme("document-edit"),
+    sessionPostNote = new QAction(QIcon::fromTheme("document-edit",
+                                                   QIcon(":/images/button-edit.png")),
                                           tr("&Post a Note"),
                                           this);
     sessionPostNote->setShortcut(QKeySequence("Ctrl+N"));
@@ -774,7 +786,8 @@ void MainWindow::createMenus()
 
     settingsMenu = new QMenu(tr("S&ettings"));
 
-    settingsEditProfile = new QAction(QIcon::fromTheme("user-properties"),
+    settingsEditProfile = new QAction(QIcon::fromTheme("user-properties",
+                                                       QIcon(":/images/no-avatar.png")),
                                       tr("Edit &Profile"), this);
     connect(settingsEditProfile, SIGNAL(triggered()),
             profileEditor, SLOT(show()));
@@ -806,6 +819,15 @@ void MainWindow::createMenus()
 
     helpMenu = new QMenu(tr("&Help"));
 
+    helpBasicHelp = new QAction(QIcon::fromTheme("help-browser"),
+                                tr("Basic &Help"), this);
+    helpBasicHelp->setShortcut(Qt::Key_F1);
+    connect(helpBasicHelp, SIGNAL(triggered()),
+            helpWidget, SLOT(show()));
+    helpMenu->addAction(helpBasicHelp);
+
+    helpMenu->addSeparator();
+
     helpVisitWebsite = new QAction(QIcon::fromTheme("internet-web-browser"),
                             tr("Visit &Website"), this);
     connect(helpVisitWebsite, SIGNAL(triggered()),
@@ -824,6 +846,12 @@ void MainWindow::createMenus()
             this, SLOT(visitTips()));
     helpMenu->addAction(helpVisitPumpTips);
 
+    helpVisitPumpUserList = new QAction(QIcon::fromTheme("internet-web-browser"),
+                                        tr("List of Some Pump.io &Users"), this);
+    connect(helpVisitPumpUserList, SIGNAL(triggered()),
+            this, SLOT(visitUserList()));
+    helpMenu->addAction(helpVisitPumpUserList);
+
 
     helpMenu->addSeparator();
 
@@ -850,10 +878,14 @@ void MainWindow::createMenus()
     trayContextMenu->addAction(trayShowWindowAction);
     trayContextMenu->addSeparator();
     trayContextMenu->addAction(sessionUpdateMainTimeline);
+    trayContextMenu->addAction(sessionUpdateMinorFeed);
     trayContextMenu->addAction(sessionMarkAllAsRead);
     trayContextMenu->addAction(sessionPostNote);
     trayContextMenu->addSeparator();
+    trayContextMenu->addAction(settingsEditProfile);
     trayContextMenu->addAction(settingsConfigure);
+    trayContextMenu->addSeparator();
+    trayContextMenu->addAction(helpBasicHelp);
     trayContextMenu->addAction(helpAbout);
     trayContextMenu->addSeparator();
     trayContextMenu->addAction(sessionQuit);
@@ -1144,6 +1176,28 @@ void MainWindow::updateConfigSettings()
     this->publicPosts = settings.value("publicPosts", false).toBool();
     this->publisher->setDefaultPublicPosting(this->publicPosts);
 
+    int selectedProxyType = settings.value("proxyType", 0).toInt(); // 0 means "no proxy"
+    QNetworkProxy::ProxyType proxyType = QNetworkProxy::NoProxy;
+    if (selectedProxyType == 1)
+    {
+        proxyType = QNetworkProxy::Socks5Proxy;
+    }
+    else if (selectedProxyType == 2)
+    {
+        proxyType = QNetworkProxy::HttpProxy;
+    }
+
+    QString proxyHostname = settings.value("proxyHostname").toString();
+    int proxyPort = settings.value("proxyPort", 0).toInt();
+    bool proxyUseAuth = settings.value("proxyUseAuth", false).toBool();
+    QString proxyUser = settings.value("proxyUser").toString();
+    QByteArray proxyPassword = QByteArray::fromBase64(settings.value("proxyPassword").toByteArray());
+
+    this->pumpController->setProxyConfig(proxyType,
+                                         proxyHostname, proxyPort,
+                                         proxyUseAuth,
+                                         proxyUser,
+                                         QString::fromLocal8Bit(proxyPassword));
 
     // Timelines & MinorFeed colors
     QStringList highlightColorsList;
@@ -1152,6 +1206,7 @@ void MainWindow::updateConfigSettings()
     highlightColorsList.append(settings.value("color3").toString());
     highlightColorsList.append(settings.value("color4").toString());
     highlightColorsList.append(settings.value("color5").toString());
+    highlightColorsList.append(settings.value("color6").toString());
 
     this->meanwhileFeed->updateHighlightColors(highlightColorsList);
     this->mainTimeline->updateHighlightColors(highlightColorsList);
@@ -1210,6 +1265,34 @@ void MainWindow::toggleWidgetsByAuthorization(bool authorized)
 }
 
 
+/*
+ * Stuff executed 1 second after MainWindow is created
+ *
+ */
+void MainWindow::postInit()
+{
+    qDebug() << "postInit();";
+
+    this->adjustTimelineSizes();
+
+    // Ask for proxy password if needed
+    if (this->pumpController->needsProxyPassword())
+    {
+        QString proxyPassword = QInputDialog::getText(this, tr("Proxy password required"),
+                                                      tr("You have configured a "
+                                                         "proxy server with "
+                                                         "authentication, but the "
+                                                         "password is not set.")
+                                                      + "\n\n"
+                                                      + tr("Enter the password "
+                                                           "for your proxy server:"),
+                                                      QLineEdit::Password);
+        // FIXME: if this is canceled, nothing will be loaded until program restart
+        this->pumpController->setProxyPassword(proxyPassword);
+    }
+}
+
+
 
 
 /*
@@ -1266,17 +1349,23 @@ void MainWindow::updateProfileData(QString avatarUrl, QString fullName,
                                    QString hometown, QString bio,
                                    QString eMail)
 {
+    QString bioTooltip = bio;
     if (!bio.isEmpty())
     {
-        bio.prepend("<b></b>"); // make it rich text, so it gets wordwrap
-        bio.replace("\n", "<br>"); // HTML newlines
+        bioTooltip.prepend("<b></b>"); // make it rich text, so it gets wordwrap
+        bioTooltip.replace("\n", "<br>"); // HTML newlines
     }
+    else
+    {
+        bioTooltip = "<i>" + tr("Your biography is empty") + "</i>";
+    }
+
     this->fullNameLabel->setText(fullName);
-    this->fullNameLabel->setToolTip(bio);
+    this->fullNameLabel->setToolTip(bioTooltip);
     this->userIdLabel->setText(this->userID);
-    this->userIdLabel->setToolTip(bio);
+    this->userIdLabel->setToolTip(bioTooltip);
     this->userHometownLabel->setText(hometown);
-    this->userHometownLabel->setToolTip(bio);
+    this->userHometownLabel->setToolTip(bioTooltip);
     qDebug() << "Updated profile data from server:" << fullName << " @" << hometown;
 
     this->avatarURL = avatarUrl;
@@ -1300,7 +1389,11 @@ void MainWindow::updateProfileData(QString avatarUrl, QString fullName,
     {
         pumpController->getAvatar(avatarURL);
     }
-    this->avatarIconButton->setToolTip(bio);
+    this->avatarIconButton->setToolTip(bioTooltip
+                                       + "<br><hr>"
+                                         "<b><i>"
+                                       + tr("Click to edit your profile")
+                                       + "</i></b>");
 
 
     // Fill/update this info in the profile editor too
@@ -1407,8 +1500,12 @@ void MainWindow::scrollFavoritesTimelineToWidget(QWidget *widget)
 void MainWindow::notifyTimelineUpdate(int timelineType,
                                       int newPostCount, int highlightCount)
 {
+    QString statusBarMessage = tr("Timeline updated.");
+
     if (newPostCount > 0)
     {
+        QString timelineUpdatedAt = tr("Timeline updated at %1.")
+                                    .arg(QTime::currentTime().toString());
         QString newPostsString;
         if (newPostCount == 1)
         {
@@ -1419,33 +1516,39 @@ void MainWindow::notifyTimelineUpdate(int timelineType,
             newPostsString = tr("There are %1 new posts.").arg(newPostCount);
         }
 
+        statusBarMessage.append(" " + newPostsString);
+
+        QString hlPostsString;
         if (highlightCount > 0)
         {
             if (highlightCount == 1)
             {
-                newPostsString.append(" " + tr("1 highlighted post."));
+                hlPostsString = tr("1 highlighted.",
+                                   "singular, refers to a post");
             }
             else
             {
-                newPostsString.append(" " + tr("%1 highlighted posts.")
-                                            .arg(highlightCount));
+                hlPostsString = tr("%1 highlighted.",
+                                   "plural, refers to posts").arg(highlightCount);
             }
+
+            statusBarMessage.append(" " + hlPostsString);
         }
 
-
-        QString statusBarMessage = tr("Timeline updated.")
-                                   + " " + newPostsString;
         this->setStatusBarMessage(statusBarMessage);
 
         // Only for the main timeline
         if (timelineType == TimeLine::TimelineTypeMain)
         {
-            if ((fdNotifier->getNotifyNewTimeline() && newPostCount > 0)
-             || (fdNotifier->getNotifyHLTimeline() && highlightCount > 0))
+            if (fdNotifier->getNotifyHLTimeline() && highlightCount > 0)
             {
-                fdNotifier->showMessage(tr("Timeline updated at %1.")
-                                        .arg(QTime::currentTime().toString())
-                                        + "\n\n"
+                fdNotifier->showMessage(timelineUpdatedAt + "\n\n"
+                                        + newPostsString + "\n"
+                                        + hlPostsString);
+            }
+            else if (fdNotifier->getNotifyNewTimeline())
+            {
+                fdNotifier->showMessage(timelineUpdatedAt + "\n\n"
                                         + newPostsString);
             }
 
@@ -1454,7 +1557,8 @@ void MainWindow::notifyTimelineUpdate(int timelineType,
     }
     else
     {
-        this->setStatusBarMessage(tr("Timeline updated. No new posts."));
+        statusBarMessage.append(" " + tr("No new posts."));
+        this->setStatusBarMessage(statusBarMessage);
     }
 
 
@@ -1597,6 +1701,8 @@ void MainWindow::setMinorFeedTitle(int newItemsCount)
 
 void MainWindow::notifyMinorFeedUpdate(int newItemsCount, int highlightedCount)
 {
+    QString statusBarMessage = tr("Minor feed updated.");
+
     if (newItemsCount > 0)
     {
         QString mwUpdatedAt = tr("Minor feed updated at %1.")
@@ -1605,35 +1711,28 @@ void MainWindow::notifyMinorFeedUpdate(int newItemsCount, int highlightedCount)
         QString newItemsString;
         if (newItemsCount == 1)
         {
-            newItemsString = tr("There is 1 new item.");
+            newItemsString = tr("There is 1 new activity.");
         }
         else
         {
-            newItemsString = tr("There are %1 new items.")
+            newItemsString = tr("There are %1 new activities.")
                              .arg(newItemsCount);
         }
 
-        QString statusBarMessage = tr("Minor feed updated.")
-                                   + " " + newItemsString;
-
-
-        if (fdNotifier->getNotifyNewMeanwhile())
-        {
-            fdNotifier->showMessage(mwUpdatedAt + "\n\n"
-                                    + newItemsString);
-        }
-
+        statusBarMessage.append(" " + newItemsString);
 
         if (highlightedCount > 0)
         {
             QString hlItemsString;
             if (highlightedCount == 1)
             {
-                hlItemsString = tr("There is 1 highlighted activity.");
+                hlItemsString = tr("1 highlighted.",
+                                   "singular, refers to an activity");
             }
             else
             {
-                hlItemsString = tr("There are %1 highlighted activities.")
+                hlItemsString = tr("%1 highlighted.",
+                                   "plural, refers to activities")
                                 .arg(highlightedCount);
             }
 
@@ -1643,14 +1742,29 @@ void MainWindow::notifyMinorFeedUpdate(int newItemsCount, int highlightedCount)
             if (fdNotifier->getNotifyHLMeanwhile())
             {
                 fdNotifier->showMessage(mwUpdatedAt + "\n\n"
+                                        + newItemsString + "\n"
                                         + hlItemsString);
             }
         }
+        else
+        {
+            if (fdNotifier->getNotifyNewMeanwhile())
+            {
+                fdNotifier->showMessage(mwUpdatedAt + "\n\n"
+                                        + newItemsString);
+            }
+
+        }
 
 
         this->setStatusBarMessage(statusBarMessage);
         this->logViewer->addToLog(statusBarMessage);
     }
+    else
+    {
+        statusBarMessage.append(" " + tr("No new activities."));
+        this->setStatusBarMessage(statusBarMessage);
+    }
 }
 
 
@@ -1946,6 +2060,12 @@ void MainWindow::visitTips()
     QDesktopServices::openUrl(QUrl("http://communicationfreedom.wordpress.com/2014/03/17/pump-io-tips/"));
 }
 
+void MainWindow::visitUserList()
+{
+    qDebug() << "Opening JPope.org user list in browser";
+    QDesktopServices::openUrl(QUrl("https://static.jpope.org/users.html"));
+}
+
 
 
 
@@ -1956,7 +2076,7 @@ void MainWindow::visitTips()
 void MainWindow::aboutDianara()
 {
     QMessageBox::about(this, tr("About Dianara"),
-                       "<b>Dianara v1.2.1</b><br>"
+                       "<b>Dianara v1.2.2</b><br>"
                        "Copyright 2012-2014  JanKusanagi<br><br>"
                        "<a href=\"http://jancoding.wordpress.com/dianara\">"
                        "http://jancoding.wordpress.com/dianara</a><br><br>"
@@ -2011,6 +2131,11 @@ void MainWindow::toggleMainWindow()
     }
 }
 
+void MainWindow::showAuthError(QString title, QString message)
+{
+    QMessageBox::warning(this, title, message);
+}
+
 
 
 /*
@@ -2028,11 +2153,39 @@ void MainWindow::quitProgram()
 
     saveSettings();
 
-    reallyQuitProgram = true;
 
-    qApp->closeAllWindows();
+    reallyQuitProgram = false;
+    if (this->publisher->isFullMode())  // If composer is active, ask for confirmation
+    {                                   // FIXME: composing comments should also block here
+        int confirmation = QMessageBox::question(this,
+                              tr("Quit?"),
+                              tr("You are composing a note or a comment.")
+                              + "\n\n"
+                              + tr("Do you really want to close Dianara?"),
+                              tr("&Yes, close the program"), tr("&No"),
+                              "", 1, 1);
+        if (confirmation == 0)
+        {
+            qDebug() << "Exit confirmed; quitting, bye!";
+            reallyQuitProgram = true;
+        }
+        else
+        {
+            qDebug() << "Confirmation canceled, not exiting";
+        }
 
-    qDebug() << "All windows closed, bye!";
+    }
+    else
+    {
+        reallyQuitProgram = true;
+    }
+
+
+    if (reallyQuitProgram)
+    {
+        qApp->closeAllWindows();
+        qDebug() << "All windows closed, bye!";
+    }
 }
 
 
