@@ -66,6 +66,7 @@
 #include "filtereditor.h"
 #include "filterchecker.h"
 #include "logviewer.h"
+#include "helpwidget.h"
 
 
 class MainWindow : public QMainWindow
@@ -94,6 +95,8 @@ public slots:
 
     void toggleWidgetsByAuthorization(bool authorized);
 
+    void postInit();
+
     void trayControl(QSystemTrayIcon::ActivationReason reason);
     void showTrayFallbackMessage(QString message);
 
@@ -147,10 +150,13 @@ public slots:
     void visitWebSite();
     void visitFAQ();
     void visitTips();
+    void visitUserList();
     void aboutDianara();
 
     void toggleMainWindow();
 
+    void showAuthError(QString title, QString message);
+
     void quitProgram();
 
 
@@ -190,9 +196,11 @@ private:
     QAction *settingsFilters;
     QAction *settingsConfigure;
 
+    QAction *helpBasicHelp;
     QAction *helpVisitWebsite;
     QAction *helpVisitPumpFAQ;
     QAction *helpVisitPumpTips;
+    QAction *helpVisitPumpUserList;
     QAction *helpAbout;
     ////////////////////////////////////// End menus
 
@@ -218,6 +226,7 @@ private:
     int tabsPosition;
     bool tabsMovable;
 
+    // User profile widgets
     QPushButton *avatarIconButton;
     QString avatarURL;
     QLabel *fullNameLabel;
@@ -239,6 +248,7 @@ private:
     FilterChecker *filterChecker;
     FilterEditor *filterEditor;
     LogViewer *logViewer;
+    HelpWidget *helpWidget;
     PumpController *pumpController;
     FDNotifications *fdNotifier;
 
@@ -274,6 +284,8 @@ private:
     QTimer *timestampsTimer;
     QTimer *delayedResizeTimer;
 
+    QTimer *postInitTimer;
+
     bool publicPosts;
 
     QString oldStatusBarMessage;
