@@ -61,9 +61,9 @@ MinorFeed::MinorFeed(PumpController *pumpController,
     this->setLayout(mainLayout);
 
 
-    // Set the 5 colors empty, on start, since they're required when creating the demo
-    // item feed, and they're not set at this point
-    highlightColorsList << "" << "" << "" << "" << "";
+    // Set the 6 colors empty, on start, since they're required when creating the demo
+    // item feed, and they're not set at this point yet
+    highlightColorsList << "" << "" << "" << "" << "" << "";
 
 
     // Demo activity, stating that there's nothing to show
@@ -167,6 +167,7 @@ void MinorFeed::updateFeed()
 {
     this->feedOffset = 0;
     this->pController->getMinorFeed();
+    //this->pController->getMinorFeedProper(this->prevLink);
 }
 
 /*
@@ -177,15 +178,21 @@ void MinorFeed::getMoreActivities()
 {
     this->feedOffset += 50;
     this->pController->getMinorFeed(feedOffset);
+    //this->pController->getMinorFeedProper(this->nextLink);
 }
 
 
 
-void MinorFeed::setFeedContents(QVariantList activitiesList)
+void MinorFeed::setFeedContents(QVariantList activitiesList,
+                                QString previous, QString next)
 {
+    this->prevLink = previous;
+    this->nextLink = next;
+    qDebug() << "MinorFeed links:" << this->prevLink << this->nextLink;
+
     this->getMoreButton->hide();
 
-    if (feedOffset == 0) // Not asking for more, but a reload
+    if (feedOffset == 0) // Didn't ask for more, but a reload
     {
         this->clearContents();
         this->newItemsCount = 0;
