@@ -47,20 +47,48 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
                                     this->pController,
                                     QSize(32,32));
 
+
+    createdAtTimestamp = activity->getCreatedAt();
+    QString timestampTooltip = "<b>"
+                               + Timestamp::localTimeDate(createdAtTimestamp)
+                               + "</b>";
+
     QString generator = activity->getGenerator();
     if (!generator.isEmpty())
     {
-        generator = "\n"
-                  + tr("using %1",
-                       "Application used to generate this activity").arg(generator);
+        timestampTooltip.append("<br>"
+                                + tr("Using %1",
+                                     "Application used to generate this activity")
+                                  .arg(generator));
+    }
+
+    QString toField = activity->getToString();
+    QString ccField = activity->getCCString();
+    if (!toField.isEmpty() || !ccField.isEmpty())
+    {
+        timestampTooltip.append("<br>"); // Extra separation before To or CC
+
+        if (!toField.isEmpty())
+        {
+            timestampTooltip.append("<br>"
+                                    + tr("To: %1",
+                                         "1=people to whom this activity was sent")
+                                      .arg(toField));
+        }
+        if (!ccField.isEmpty())
+        {
+            timestampTooltip.append("<br>"
+                                    + tr("CC: %1",
+                                         "1=people to whom this activity was sent as CC")
+                                      .arg(ccField));
+        }
     }
 
-    createdAtTimestamp = activity->getCreatedAt();
     timestampLabel = new QLabel();
     mainFont.setBold(true);
     timestampLabel->setFont(mainFont);
     timestampLabel->setWordWrap(true);
-    timestampLabel->setToolTip(Timestamp::localTimeDate(createdAtTimestamp) + generator);
+    timestampLabel->setToolTip(timestampTooltip.trimmed());
     timestampLabel->setAlignment(Qt::AlignCenter);
     timestampLabel->setAutoFillBackground(true);
     timestampLabel->setForegroundRole(QPalette::Text);
@@ -152,6 +180,8 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
         }
     }
 
+    activityTooltip = activityTooltip.trimmed();
+
     // If the tooltip is only this, remove it / FIXME
     if (activityTooltip == "<b></b>")
     {
@@ -164,15 +194,12 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     activityDescriptionLabel->setFont(mainFont);
     activityDescriptionLabel->setWordWrap(true);
     activityDescriptionLabel->setOpenExternalLinks(true);
-    activityDescriptionLabel->setToolTip(activityTooltip.trimmed());
     connect(activityDescriptionLabel, SIGNAL(linkHovered(QString)),
             this, SLOT(showUrlInfo(QString)));
 
+    // Set the activity info as tooltip for the whole widget, not only the label
+    this->setToolTip(activityTooltip);
 
-    openButton = new QPushButton("+");
-    openButton->setSizePolicy(QSizePolicy::Ignored,
-                              QSizePolicy::Maximum);
-    openButton->setToolTip(tr("Open referenced post"));
 
     originalObjectMap = activity->object()->getOriginalObject();
 
@@ -287,6 +314,10 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
             || activity->object()->getType() == "file")
           && activity->object()->getDeletedTime().isEmpty() ) )
     {
+        this->openButton = new QPushButton("+");
+        openButton->setSizePolicy(QSizePolicy::Ignored,
+                                  QSizePolicy::Maximum);
+        openButton->setToolTip(tr("Open referenced post"));
         connect(openButton, SIGNAL(clicked()),
                 this, SLOT(openOriginalPost()));
         leftLayout->addWidget(openButton, 0, Qt::AlignHCenter);
@@ -416,7 +447,7 @@ void MinorFeedItem::openOriginalPost()
     ASActivity *originalPostActivity = new ASActivity(originalPostMap, this);
 
     QStringList colorsList;
-    colorsList << "" << "" << "" << "" << ""; // Empty color list, needs 5 colors to avoid crashes
+    colorsList << "" << "" << "" << "" << "" << ""; // Empty color list, needs 6 colors to avoid crashes
 
     Post *referencedPost = new Post(originalPostActivity,
                                     colorsList,
