@@ -91,6 +91,45 @@ QString MiscHelpers::getCachedImageFilename(QString url)
 }
 
 
+/*
+ * Generate suggested filename for an attachment,
+ * based on author ID, original extension, etc.
+ *
+ */
+QString MiscHelpers::getSuggestedFilename(QString authorId,
+                                          QString postType,
+                                          QString postTitle,
+                                          QString fileUrl)
+{
+    // Get original filename in server
+    QString originalFilename = fileUrl.split("/").last();
+
+    QString suggestedFilename = authorId;
+    suggestedFilename.append("_" + postType);
+    if (!postTitle.trimmed().isEmpty())
+    {
+        suggestedFilename.append("_" + postTitle);
+    }
+
+    suggestedFilename.replace("@", "-"); // Avoid certain chars from author ID
+    suggestedFilename.replace(".", "-");
+    suggestedFilename.replace("/", "-");
+    suggestedFilename.remove("?");
+    suggestedFilename.remove("!");
+    suggestedFilename.remove("*");
+    suggestedFilename.remove(":");
+    suggestedFilename.remove(";");
+
+    suggestedFilename.replace(" ", "_"); // Avoid spaces in filename
+
+    suggestedFilename.append("_" + originalFilename); // Something like A53r2w.png
+
+    // Extension will be .bin for generic files, at the moment
+
+    return suggestedFilename;
+}
+
+
 
 /*
  * Return MIME content type, like image/png, audio/ogg, etc.
@@ -146,6 +185,30 @@ int MiscHelpers::getImageWidth(QString fileURI)
 }
 
 
+bool MiscHelpers::isImageAnimated(QString fileUri)
+{
+    qDebug() << "QMovie::supportedFormats()" << QMovie::supportedFormats();
+
+    bool isAnimated = false;
+
+    QImageReader imageReader(fileUri);
+    if (imageReader.supportsAnimation())
+    {
+        QMovie movie;
+        movie.setFileName(fileUri);
+        qDebug() << "Image format SUPPORTS animation; Frames:" << movie.frameCount();
+        if (movie.frameCount() > 1) // FIXME: doesn't work with .MNG, so it returns 0
+        {
+            qDebug() << "Image IS animated.";
+            isAnimated = true;
+        }
+    }
+
+
+    return isAnimated;
+}
+
+
 
 QString MiscHelpers::fixLongName(QString name)
 {
@@ -208,6 +271,7 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
 
     //qDebug() << "MiscHelpers::htmlWithReplacedImages(); HTML contains some <img> tags...";
     QString newHtml = originalHtml;
+    newHtml.remove("\n"); // Remove in case misbehaving applications added any
 
     QStringList imageList;
     QString imgSrc;
@@ -278,13 +342,46 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
     QRegExp headRE("<html><head>.*</head>");
     headRE.setMinimal(true);
     cleanHtml.remove(headRE);
-    cleanHtml.remove("</body></html>");
 
     QRegExp bodyRE("<body style.*>");
     bodyRE.setMinimal(true);
-
     cleanHtml.remove(bodyRE);
 
+    //////////////////////////////////////// Remove <span style=...> from links
+    QRegExp linkStyleRE("<a href=.*>.*</a>");
+    linkStyleRE.setMinimal(true);
+    QRegExp spanRE("<span style=.*>(.*)</span>");
+    spanRE.setMinimal(true);
+
+    int pos = 0;
+    while ((pos = linkStyleRE.indexIn(cleanHtml, pos)) != -1)
+    {
+        int removedTextOffset = 0;
+        if (spanRE.indexIn(cleanHtml, pos) != -1)
+        {
+            // Replace the whole span tag by just what was inside
+            cleanHtml.replace(spanRE.cap(0), spanRE.cap(1));
+            //qDebug() << "spanRE capture: " << spanRE.capturedTexts();
+            removedTextOffset = spanRE.cap(0).length() - spanRE.cap(1).length();
+        }
+
+        pos += linkStyleRE.matchedLength() - removedTextOffset;
+    }
+
+    /////////////////////////////////////////// Remove style from <ul> and <li>
+    QRegExp ulStyleRE("<ul style.*>");
+    ulStyleRE.setMinimal(true);
+    cleanHtml.replace(ulStyleRE, "<ul>");
+
+    QRegExp liStyleRE("<li style.*>");
+    liStyleRE.setMinimal(true);
+    cleanHtml.replace(liStyleRE, "<li>");
+
+
+    // FIXME: Maybe try to remove background colors from <p> elements
+
+    cleanHtml.remove("</body></html>");
+
     return cleanHtml.trimmed();
 }
 
@@ -303,10 +400,62 @@ QString MiscHelpers::quotedText(QString author, QString content)
     content = textDocument.toPlainText().trimmed();
     content.replace("\n", "<br>");
 
-    QString quoteHtml = "&gt;&gt; <b><u>"+ author + ":</u></b>"  // >>> + name
+    QString quoteHtml = "&gt;&gt; <b><u>"+ author + ":</u></b>"  // >> + name
                         "<blockquote>"
                         "<small><i>&ldquo;" + content + "&rdquo;</i></small>"
                         "</blockquote> <br>";
 
     return quoteHtml;
 }
+
+
+
+/*
+ * Generate the first part of the HTML of a post
+ * that includes media attachments
+ *
+ */
+QString MiscHelpers::mediaHtmlBase(QString postType,
+                                   QString attachmentFilename,
+                                   QString tooltipMessage,
+                                   QString belowMessage,
+                                   int imageWidth)
+{
+    QString html = "<table cellpadding=4 width=100% "
+                   "style=\" "
+                   "border-style: solid; "
+                   "border-width: 1px; "
+                   "margin: 2px; \" >"
+                   // First row, with gradient
+                   "<tr style=\" "
+                   "background-color: "
+                   "qlineargradient(spread:reflect, "
+                   "x1:0, y1:0, x2:0.5, y2:0, "
+                   "stop:0 rgba(255, 255, 255, 0), "
+                   "stop:1 palette(highlight) ); "
+                   "\" >"
+                   "<td align=center>"
+                   "<a title=\"" + tooltipMessage + "\" href";
+
+    if (postType == "image")
+    {
+        html.append("=\"image:/" + attachmentFilename + "\" >");
+    }
+    else
+    {
+        html.append("=\"attachment:/\" >");
+    }
+
+    html.append("<img src=\"" + attachmentFilename +  "\" "
+                "width=\"" + QString("%1").arg(imageWidth) + "\" />"
+                "</a></td></tr>");
+
+    // Second row, to add a message related to the image or attachment
+    html.append("<tr><td align=center><small>"
+                + belowMessage +
+                "</small></td></tr>"
+                "</table>"
+                "<br><br>");
+
+    return html;
+}
