@@ -29,8 +29,9 @@
 #include <QFileInfo>
 #include <QTextDocument>
 #include <QImageReader>
+#include <QMovie>
 
-#include <QDesktopServices> // TMP: getting avatar directory
+#include <QDesktopServices>
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QStandardPaths>
 #endif
@@ -50,18 +51,27 @@ public:
     static QString getCachedAvatarFilename(QString url);
     static QString getCachedImageFilename(QString url);
 
+    static QString getSuggestedFilename(QString authorId, QString postType,
+                                        QString postTitle, QString fileUrl);
+
     static QString getFileMimeType(QString fileUri);
     static int getImageWidth(QString fileURI);
+    static bool isImageAnimated(QString fileUri);
 
     static QString fixLongName(QString name);
 
     static QString fileSizeString(QString fileURI);
 
-    static QStringList htmlWithReplacedImages(QString originalHtml, int postWidth);
+    static QStringList htmlWithReplacedImages(QString originalHtml,
+                                              int postWidth);
     static QString cleanupHtml(QString originalHtml);
 
     static QString quotedText(QString author, QString content);
 
+    static QString mediaHtmlBase(QString postType, QString attachmentFilename,
+                                 QString tooltipMessage, QString belowMessage,
+                                 int imageWidth = -1);
+
 };
 
 #endif // MISCHELPERS_H
