@@ -37,12 +37,11 @@ FDNotifications::FDNotifications()
             {
                 if (serviceName == "org.freedesktop.Notifications")
                 {
-                    qDebug() << "org.freedesktop.Notifications service found!";
+                    qDebug() << "org.freedesktop.Notifications DBus service found!";
                     this->notificationsAvailable = true;
                 }
             }
         }
-
     }
     else
     {
@@ -69,15 +68,50 @@ bool FDNotifications::areNotificationsAvailable()
     return notificationsAvailable;
 }
 
-void FDNotifications::setNotificationType(int type)
+void FDNotifications::setNotificationOptions(int style,
+                                             bool notifyNewTL, bool notifyHLTL,
+                                             bool notifyNewMW, bool notifyHLMW)
 {
-    this->notificationType = type;
-    qDebug() << "Notification type set to" << type << "-- FD.o/Qt/none";
+    this->notificationType = style;
+
+    this->notifyNewTimeline  = notifyNewTL;
+    this->notifyHLTimeline   = notifyHLTL;
+    this->notifyNewMeanwhile = notifyNewMW;
+    this->notifyHLMeanwhile  = notifyHLMW;
+
+    qDebug() << "Notification type set to"
+             << this->notificationType
+             << "-- FD.o/Qt/none";
+    qDebug() << this->notifyNewTimeline << this->notifyHLTimeline
+             << this->notifyNewMeanwhile << this->notifyHLMeanwhile;
+}
+
+
+bool FDNotifications::getNotifyNewTimeline()
+{
+    return this->notifyNewTimeline;
+}
+
+bool FDNotifications::getNotifyHLTimeline()
+{
+    return this->notifyHLTimeline;
+}
+
+bool FDNotifications::getNotifyNewMeanwhile()
+{
+    return this->notifyNewMeanwhile;
+}
+
+bool FDNotifications::getNotifyHLMeanwhile()
+{
+    return this->notifyHLMeanwhile;
 }
 
 
 
-//////////////////////////// SLOTS //////////////////////////////////
+///////////////////////////////////////////////////////////////////////
+////////////////////////////// SLOTS //////////////////////////////////
+///////////////////////////////////////////////////////////////////////
 
 
 
@@ -135,11 +169,11 @@ void FDNotifications::showMessage(QString message)
     {
         arguments << QString("dialog-information");   // app_icon otherwise
     }
-    arguments << QString(tr("Dianara Notification"));
+    arguments << QString(tr("Dianara Activity"));
     arguments << message;
     arguments << QStringList();        // actions
     arguments << QVariantMap();        // hints
-    arguments << 5000;                 // timeout, milliseconds
+    arguments << 4000;                 // timeout, milliseconds
 
     dBusMessage.setArguments(arguments);
 
