@@ -38,7 +38,16 @@ public:
     ~FDNotifications();
 
     bool areNotificationsAvailable();
-    void setNotificationType(int type);
+    void setNotificationOptions(int style,
+                                bool notifyNewTL,
+                                bool notifyHLTL,
+                                bool notifyNewMW,
+                                bool notifyHLMW);
+    bool getNotifyNewTimeline();
+    bool getNotifyHLTimeline();
+    bool getNotifyNewMeanwhile();
+    bool getNotifyHLMeanwhile();
+
 
     enum notificationTypes
     {
@@ -47,18 +56,25 @@ public:
         NoNotifications
     };
 
+
 signals:
     void showFallbackNotification(QString message);
 
+
 public slots:
     void showMessage(QString message);
 
+
 private:
-    bool notificationsAvailable;
-    int notificationType;
     QDBusConnection *bus;
 
+    bool notificationsAvailable;
 
+    int notificationType;
+    bool notifyNewTimeline;
+    bool notifyHLTimeline;
+    bool notifyNewMeanwhile;
+    bool notifyHLMeanwhile;
 };
 
 #endif // NOTIFICATIONS_H
