@@ -63,7 +63,8 @@ PeopleWidget::PeopleWidget(QString buttonText,
             this, SLOT(returnClickedContact(QModelIndex)));
 
 
-    addToButton = new QPushButton(QIcon::fromTheme("list-add"),
+    addToButton = new QPushButton(QIcon::fromTheme("list-add",
+                                                   QIcon(":/images/list-add.png")),
                                   buttonText);
     connect(addToButton, SIGNAL(clicked()),
             this, SLOT(returnContact()));
@@ -99,7 +100,8 @@ PeopleWidget::PeopleWidget(QString buttonText,
 
         allContactsListView->setSelectionMode(QListView::SingleSelection);
 
-        cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel"),
+        cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
+                                                        QIcon(":/images/button-cancel.png")),
                                        tr("&Cancel"));
         connect(cancelButton, SIGNAL(clicked()),
                 this, SLOT(hide()));
