@@ -163,6 +163,7 @@ private:
     QString postId;
     QString postType;
     QString postUrl;
+    QString postAuthorId;
     QString postAuthorName;
 
     QString postSharedById;
@@ -173,6 +174,7 @@ private:
     bool postIsOwn;
     bool postIsUnread;
     int highlightType;
+    QString unreadPostColor;
 
     AvatarButton *postAuthorAvatarButton;
     QAction *openPostInBrowserAction;
@@ -206,10 +208,12 @@ private:
 
     QString postTitle;
     QString postImageUrl;
+    bool postImageIsAnimated;
     QString postAudioUrl;
     QString postVideoUrl;
     QString postFileUrl;
     QString postFileMimeType;
+    QString postAttachmentPureUrl;
     QString postOriginalText;
 
     QString postCreatedAtString;
@@ -229,6 +233,7 @@ private:
     bool standalone;
 
     QString seeFullImageString;
+    QString downloadAttachmentString;
 
     PumpController *pController;
     CommenterBlock *commenter;
