@@ -49,19 +49,22 @@ Publisher::Publisher(PumpController *pumpController,
             this, SLOT(updateToCcFields(QString,QStringList)));
 
 
-    QString titleTooltip = tr("Brief title for the post. Setting a "
-                              "title helps make the Meanwhile feed "
-                              "more informative.") + "<b></b>";
+    QString titleTooltip = tr("Setting a title helps make the Meanwhile feed "
+                              "more informative") + "<b></b>";
 
+    QFont titleFont;
+    titleFont.setBold(true);
     titleLabel = new QLabel(tr("Title") + ":");
     titleLabel->setSizePolicy(QSizePolicy::Minimum,
                               QSizePolicy::Maximum);
+    titleLabel->setFont(titleFont);
     titleLabel->setToolTip(titleTooltip);
 
     titleLineEdit = new QLineEdit();
     titleLineEdit->setSizePolicy(QSizePolicy::MinimumExpanding,
                                  QSizePolicy::Maximum);
-    titleLineEdit->setPlaceholderText(tr("Title for the post"));
+    titleLineEdit->setPlaceholderText(tr("Add a brief title for the post (recommended)"));
+    titleLineEdit->setFont(titleFont);
     titleLineEdit->setToolTip(titleTooltip);
 
 
@@ -101,6 +104,15 @@ Publisher::Publisher(PumpController *pumpController,
     connect(composerBox, SIGNAL(editingCancelled()),
             this, SLOT(setMinimumMode()));
 
+    // Pressing Enter in title goes to message body
+    connect(titleLineEdit, SIGNAL(returnPressed()),
+            composerBox, SLOT(setFocus()));
+
+    // Likewise, pressing UP at the start of the body goes to title
+    connect(composerBox, SIGNAL(focusTitleRequested()),
+            titleLineEdit, SLOT(setFocus()));
+
+
     // Add formatting button exported from Composer
     this->toolsButton = composerBox->getToolsButton();
 
@@ -481,6 +493,12 @@ void Publisher::toggleWidgetsWhileSending(bool widgetsEnabled)
 }
 
 
+bool Publisher::isFullMode()
+{
+    return this->fullMode;
+}
+
+
 
 /********************************************************************/
 /***************************** SLOTS ********************************/
@@ -598,6 +616,8 @@ void Publisher::setMinimumMode()
         this->ccSelectorButton->setEnabled(true);
         this->addMediaButton->setEnabled(true);
     }
+
+    this->fullMode = false;
 }
 
 
@@ -640,6 +660,8 @@ void Publisher::setFullMode()
 
     this->composerBox->setFocus(); // In case user used menu or shortcut
                                    // instead of clicking on it
+
+    this->fullMode = true;
 }
 
 
@@ -767,6 +789,11 @@ void Publisher::setEditingMode(QString postID, QString postText,
     this->ccSelectorButton->setDisabled(true);
     this->addMediaButton->setDisabled(true);
 
+    // Clear these, so it doesn't look like the audience is different than when originally posted
+    this->toPublicFollowersLabel->clear();
+    this->toAudienceLabel->clear();
+    this->ccPublicFollowersLabel->clear();
+    this->ccAudienceLabel->clear();
 
     this->statusInfoLabel->setText(tr("Editing post"));
 }
@@ -1083,7 +1110,8 @@ void Publisher::findMediaFile()
     if (postType == "image")
     {
         findDialogTitle = tr("Select one image");
-        mediaTypes = tr("Image files") + "(*.png *.jpg *.jpeg *.gif);;";
+        mediaTypes = tr("Image files") + " (*.png *.jpg *.jpeg *.jpe"
+                                         " *.gif *.mng *.webp *.svg);;";
 
         errorTitle =  tr("Invalid image");
         errorMessage = tr("The image format cannot be detected.\n"
@@ -1093,7 +1121,8 @@ void Publisher::findMediaFile()
     else if (postType == "audio")
     {
         findDialogTitle = tr("Select one audio file");
-        mediaTypes = tr("Audio files") + "(*.ogg *.flac *.mp3 *.wav);;";
+        mediaTypes = tr("Audio files") + " (*.ogg *.oga *.flac *.mka"
+                                         " *.mp3 *.mpga *.wav *.wma);;";
 
         errorTitle = tr("Invalid audio file");
         errorMessage = tr("The audio format cannot be detected.");
@@ -1101,7 +1130,9 @@ void Publisher::findMediaFile()
     else if (postType == "video")
     {
         findDialogTitle = tr("Select one video file");
-        mediaTypes = tr("Video files") + "(*.avi *.mpg *.mpeg *.ogm *.mkv *.mp4);;";
+        mediaTypes = tr("Video files") + " (*.avi *.mpg *.mpeg *.mpe *.mpv"
+                                         " *.ogm *.ogg *.mkv *.mp4 *.webm"
+                                         " *.mov *.flv *.3gp *.wmv);;";
 
         errorTitle = tr("Invalid video file");
         errorMessage = tr("The video format cannot be detected.");
@@ -1136,7 +1167,10 @@ void Publisher::findMediaFile()
             if (postType == "image")
             {
                 QPixmap imagePixmap = QPixmap(filename);
-                // FIXME: check imagePixmap.isNull() ?
+                if (imagePixmap.isNull())
+                {
+                    QMessageBox::warning(this, errorTitle, errorMessage);
+                }
                 this->pictureLabel->setPixmap(imagePixmap.scaled(320, 180,  // 16:9
                                                                  Qt::KeepAspectRatio,
                                                                  Qt::SmoothTransformation));
