@@ -58,6 +58,8 @@ public:
     void setMediaModeWidgets();
     void toggleWidgetsWhileSending(bool widgetsEnabled);
 
+    bool isFullMode();
+
 
 signals:
 
@@ -165,6 +167,8 @@ private:
     bool editingMode;
     QString editingPostId;
 
+    bool fullMode;
+
     QNetworkReply *uploadNetworkReply;
 
     PumpController *pController;
