@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,20 +22,20 @@
 
 PumpController::PumpController(QObject *parent) :  QObject(parent)
 {
-    this->userAgentString = "Dianara/1.2.1";
+    this->userAgentString = "Dianara/1.2.2";
 
     this->postsPerPageMain = 20;
     this->postsPerPageOther = 10;
     this->updatesToTimelineBlocked = false;
 
+    this->proxyUsesAuth = false;
 
     qoauth = new QOAuth::Interface();
     qoauth->setRequestTimeout(10000); // 10 sec timeout
 
-
     QSettings settings;
-    this->clientID = settings.value("clientID", "").toString();
-    this->clientSecret = settings.value("clientSecret", "").toString();
+    this->clientID = settings.value("clientID").toString();
+    this->clientSecret = settings.value("clientSecret").toString();
     qoauth->setConsumerKey(clientID.toLocal8Bit());
     qoauth->setConsumerSecret(clientSecret.toLocal8Bit());
 
@@ -46,11 +46,11 @@ PumpController::PumpController(QObject *parent) :  QObject(parent)
     {
         qDebug() << "Dianara is already authorized for user ID:" << settings.value("userID").toString();
 
-        this->token = settings.value("token", "").toString().toLocal8Bit();
-        this->tokenSecret = settings.value("tokenSecret", "").toString().toLocal8Bit();
+        this->token = settings.value("token").toString().toLocal8Bit();
+        this->tokenSecret = settings.value("tokenSecret").toString().toLocal8Bit();
 
         qDebug() << "Using token" << token;
-        qDebug() << "And token secret" << tokenSecret;
+        qDebug() << "And token secret" << tokenSecret.left(5) + "********** (hidden)";
     }
 
 
@@ -64,6 +64,7 @@ PumpController::PumpController(QObject *parent) :  QObject(parent)
 
 
     this->initialDataStep = 0;
+    this->initialDataAttempts = 0;
 
     initialDataTimer = new QTimer(this);
     initialDataTimer->setSingleShot(false); // Triggered constantly until stopped
@@ -82,6 +83,51 @@ PumpController::~PumpController()
 }
 
 
+void PumpController::setProxyConfig(QNetworkProxy::ProxyType proxyType,
+                                    QString hostname, int port,
+                                    bool useAuth,
+                                    QString user, QString password)
+{
+    QNetworkProxy proxy;
+    proxy.setType(proxyType);
+    proxy.setHostName(hostname);
+    proxy.setPort(port);
+    if (useAuth)
+    {
+        proxy.setUser(user);
+        proxy.setPassword(password);
+
+        // If using auth, and proxy type is set
+        if (proxyType != QNetworkProxy::NoProxy)
+        {
+            this->proxyUsesAuth = true;
+        }
+    }
+    nam.setProxy(proxy);
+    qoauth->networkAccessManager()->setProxy(proxy);
+
+    qDebug() << "Proxy config applied:" << hostname << port << user;
+}
+
+bool PumpController::needsProxyPassword()
+{
+    if (this->proxyUsesAuth && this->nam.proxy().password().isEmpty())
+    {
+        return true;
+    }
+
+    return false;
+}
+
+void PumpController::setProxyPassword(QString password)
+{
+    QNetworkProxy proxy = this->nam.proxy();
+    proxy.setPassword(password);
+    this->nam.setProxy(proxy);
+    this->qoauth->networkAccessManager()->setProxy(proxy);
+}
+
+
 
 void PumpController::setPostsPerPageMain(int ppp)
 {
@@ -152,14 +198,20 @@ void PumpController::setUserCredentials(QString userID)
 
     emit this->authorizationStatusChanged(isApplicationAuthorized);
 
-    // This will call getUserProfile(), getContactList(), getMainTimeline(), etc.
     this->haveProfile = false;
     this->haveFollowing = false;
     this->haveFollowers = false;
     this->havePersonLists = false;
+    this->haveMainTL = false;
+    this->haveDirectTL = false;
+    this->haveActivityTL = false;
+    this->haveFavoritesTL = false;
+    this->haveMinorFeed = false;
 
     this->initialDataStep = 0;
+    this->initialDataAttempts = 0;
 
+    // This will call getUserProfile(), getContactList(), getMainTimeline()...
     if (isApplicationAuthorized)
     {
         this->initialDataTimer->start(2000);  // start 2 seconds after setting the ID
@@ -209,7 +261,8 @@ void PumpController::getUserProfile(QString userID)
 
     QString url = "https://" + splittedUserID.at(1) + "/api/user/" + splittedUserID.at(0);
 
-    QNetworkRequest userProfileRequest = this->prepareRequest(url, QOAuth::GET, UserProfileRequest);
+    QNetworkRequest userProfileRequest = this->prepareRequest(url, QOAuth::GET,
+                                                              UserProfileRequest);
     nam.get(userProfileRequest);
 
     qDebug() << "Requested user profile:" << userProfileRequest.url().toString();
@@ -455,8 +508,7 @@ void PumpController::getListsList()
     QString url = "https://" + this->serverURL + "/api/user/" +this->userName + "/lists/person";
 
     QNetworkRequest listsListRequest = this->prepareRequest(url, QOAuth::GET,
-                                                            ListsListRequest,
-                                                            QOAuth::ParamMap());
+                                                            ListsListRequest);
 
     emit currentJobChanged(tr("Getting list of person lists..."));
 
@@ -585,7 +637,6 @@ void PumpController::removePersonFromList(QString listId, QString personId)
     QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
                                                        RemoveMemberFromListRequest);
 
-
     QVariantMap jsonVariantObject;
     jsonVariantObject.insert("objectType", "person");
     jsonVariantObject.insert("id", personId);
@@ -638,7 +689,8 @@ void PumpController::getMainTimeline(int timelineOffset)
     paramMap.insert("offset", QString("%1").arg(timelineOffset).toLocal8Bit());
 
     QNetworkRequest timelineRequest = this->prepareRequest(url, QOAuth::GET,
-                                                           MainTimelineRequest, paramMap);
+                                                           MainTimelineRequest,
+                                                           paramMap);
 
 /*
     qDebug() << "===================================";
@@ -678,7 +730,8 @@ void PumpController::getDirectTimeline(int timelineOffset)
     paramMap.insert("offset", QString("%1").arg(timelineOffset).toLocal8Bit());
 
     QNetworkRequest timelineRequest = this->prepareRequest(url, QOAuth::GET,
-                                                           DirectTimelineRequest, paramMap);
+                                                           DirectTimelineRequest,
+                                                           paramMap);
 
     nam.get(timelineRequest);
 }
@@ -709,7 +762,8 @@ void PumpController::getActivityTimeline(int timelineOffset)
     paramMap.insert("offset", QString("%1").arg(timelineOffset).toLocal8Bit());
 
     QNetworkRequest timelineRequest = this->prepareRequest(url, QOAuth::GET,
-                                                           ActivityTimelineRequest, paramMap);
+                                                           ActivityTimelineRequest,
+                                                           paramMap);
 
     nam.get(timelineRequest);
 }
@@ -740,7 +794,8 @@ void PumpController::getFavoritesTimeline(int timelineOffset)
     paramMap.insert("offset", QString("%1").arg(timelineOffset).toLocal8Bit());
 
     QNetworkRequest timelineRequest = this->prepareRequest(url, QOAuth::GET,
-                                                           FavoritesTimelineRequest, paramMap);
+                                                           FavoritesTimelineRequest,
+                                                           paramMap);
 
     nam.get(timelineRequest);
 }
@@ -805,19 +860,19 @@ void PumpController::getTimeline(int timelineType, QString url)
  * Get list of people who liked a specific post
  *
  */
-void PumpController::getPostLikes(QString postLikesURL)
+void PumpController::getPostLikes(QString postLikesUrl)
 {
-    qDebug() << "Getting likes for post" << postLikesURL;
+    qDebug() << "Getting likes for post" << postLikesUrl;
 
     emit currentJobChanged(tr("Getting likes..."));
 
-
     QOAuth::ParamMap paramMap;
     paramMap.insert("count", "100"); // TMP, up to 100 likes
 
-    QNetworkRequest likesRequest = this->prepareRequest(postLikesURL, QOAuth::GET,
-                                                        PostLikesRequest, paramMap);
-
+    QNetworkRequest likesRequest = this->prepareRequest(postLikesUrl,
+                                                        QOAuth::GET,
+                                                        PostLikesRequest,
+                                                        paramMap);
     nam.get(likesRequest);
 }
 
@@ -830,9 +885,9 @@ void PumpController::getPostLikes(QString postLikesURL)
  * or proxyed URL. URL is given by the post itself anyway
  *
  */
-void PumpController::getPostComments(QString postCommentsURL)
+void PumpController::getPostComments(QString postCommentsUrl)
 {
-    qDebug() << "Getting comments for post" << postCommentsURL;
+    qDebug() << "Getting comments for post" << postCommentsUrl;
 
     emit currentJobChanged(tr("Getting comments..."));
 
@@ -840,8 +895,10 @@ void PumpController::getPostComments(QString postCommentsURL)
     QOAuth::ParamMap paramMap;
     paramMap.insert("count", "200"); // TMP, up to 200 comments / FIXME?
 
-    QNetworkRequest commentsRequest = this->prepareRequest(postCommentsURL, QOAuth::GET,
-                                                           PostCommentsRequest, paramMap);
+    QNetworkRequest commentsRequest = this->prepareRequest(postCommentsUrl,
+                                                           QOAuth::GET,
+                                                           PostCommentsRequest,
+                                                           paramMap);
 
     nam.get(commentsRequest);
 }
@@ -851,9 +908,9 @@ void PumpController::getPostComments(QString postCommentsURL)
  * Get list of people who shared a specific post
  *
  */
-void PumpController::getPostShares(QString postSharesURL)
+void PumpController::getPostShares(QString postSharesUrl)
 {
-
+    // TODO
 }
 
 
@@ -874,10 +931,45 @@ void PumpController::getMinorFeed(int offset)
     paramMap.insert("count", "50");
     paramMap.insert("offset", QString("%1").arg(offset).toLocal8Bit());
 
-    QNetworkRequest timelineRequest = this->prepareRequest(url, QOAuth::GET,
-                                                           MinorFeedRequest, paramMap);
+    QNetworkRequest feedRequest = this->prepareRequest(url, QOAuth::GET,
+                                                       MinorFeedRequest,
+                                                       paramMap);
+    nam.get(feedRequest);
+}
 
-    nam.get(timelineRequest);
+
+void PumpController::getMinorFeedProper(QString url)
+{
+    emit currentJobChanged(tr("Getting minor feed...") + " [PROPER/testing]"); // FIXME
+
+    QOAuth::ParamMap paramMap;
+    //paramMap.insert("count", "50");
+
+    if (url.isEmpty())
+    {
+        url = "https://" + this->serverURL + "/api/user/" + this->userName + "/inbox/minor";
+    }
+    else
+    {
+        QStringList splitUrl = url.split("?");
+        url = splitUrl.at(0);
+        QStringList splitParams = splitUrl.at(1).split("=");
+
+        paramMap.insert(splitParams.at(0).toUtf8(),
+                        //QString("https://blah").toUtf8());
+                        //QByteArray::fromPercentEncoding(splitParams.at(1).toLocal8Bit()));
+                        splitParams.at(1).toUtf8());
+    }
+
+    QNetworkRequest feedRequest = this->prepareRequest(url, QOAuth::GET,
+                                                       MinorFeedRequest,
+                                                       paramMap);
+
+    qDebug() << "****\nfeedRequest:\n";
+    qDebug() << feedRequest.rawHeader("Authorization");
+    qDebug() << "\n*\n\nURL: " << feedRequest.url().toString() << "\n\n*******";
+
+    nam.get(feedRequest);
 }
 
 
@@ -897,6 +989,7 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
                                                                  QOAuth::HMAC_SHA1,
                                                                  paramMap,
                                                                  QOAuth::ParseForHeaderArguments);
+    //qDebug() << "QOAuth::error()" << qoauth->error() << " (200=OK)";
 
     QNetworkRequest request;
 
@@ -906,7 +999,9 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
         url.append(qoauth->inlineParameters(paramMap,
                                             QOAuth::ParseForInlineQuery));
     }
+
     request.setUrl(QUrl(url));
+
     // Only add Authorization header if we're requesting something in our server
     if (request.url().host() == this->serverURL)
     {
@@ -915,7 +1010,6 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
     request.setHeader(QNetworkRequest::ContentTypeHeader, contentTypeString);
     request.setRawHeader("User-Agent", userAgentString);
 
-
     request.setAttribute(QNetworkRequest::User, QVariant(requestType));
 
     return request;
@@ -926,7 +1020,7 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
 /*
  * Upload a file to the /uploads feed for the user
  *
- * Used to upload pictures, but might have more uses in the future
+ * Used to upload pictures, audio, video and misc files
  *
  */
 QNetworkReply *PumpController::uploadFile(QString filename,
@@ -1047,7 +1141,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
     QString prettyLogMessage;
 
     qDebug() << "Request finished. HTTP code:" << httpCode;
-    qDebug() << "Size:" << reply->size() << "bytes; URL:" << replyUrl;
+    qDebug() << "Size:" << replyData.length() << "bytes; URL:" << replyUrl;
     qDebug() << "isFinished()?" << finished << "; Request type:" << requestType;
 
     // We got all necessary data, clean up
@@ -1084,14 +1178,29 @@ void PumpController::requestFinished(QNetworkReply *reply)
     }
 
 
+    const QString httpErrorString = tr("HTTP error",
+                                       "For the following HTTP error codes"
+                                       "you can check "
+                                       "http://en.wikipedia.org/wiki/List_of_HTTP_status_codes "
+                                       "in your language") + ": ";
     QString errorTypeString;
 
-
     switch (httpCode)
     {
     //////////////////////////////////////////////// First, handle error codes
+    case 504:
+        errorTypeString = httpErrorString
+                        + tr("Gateway Timeout", "HTTP 504 error string")
+                        + " (504)";
+        emit currentJobChanged(errorTypeString + ": " + replyUrl);
+        emit logMessage(errorTypeString, replyUrl);
+        qDebug() << "HTTP 504: Gateway Timeout.";
+        qDebug() << "Data:  " << replyData;
+        return;
+
     case 503:
-        errorTypeString = tr("Service Unavailable", "HTTP 503 error string")
+        errorTypeString = httpErrorString
+                        + tr("Service Unavailable", "HTTP 503 error string")
                         +  " (503) " + replyFirstLine;
 
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
@@ -1108,7 +1217,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
         return;
 
     case 500:
-        errorTypeString = tr("Internal Server Error", "HTTP 500 error string")
+        errorTypeString = httpErrorString
+                        + tr("Internal Server Error", "HTTP 500 error string")
                         + " (500) " + replyFirstLine;
 
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
@@ -1128,7 +1238,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
     case 410:
-        errorTypeString = tr("Gone", "HTTP 410 error string")
+        errorTypeString = httpErrorString
+                        + tr("Gone", "HTTP 410 error string")
                         + " (410)";
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
         emit logMessage(errorTypeString, replyUrl);
@@ -1137,7 +1248,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
         return;
 
     case 404:
-        errorTypeString = tr("Not Found", "HTTP 404 error string")
+        errorTypeString = httpErrorString
+                        + tr("Not Found", "HTTP 404 error string")
                         + " (404)";
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
         emit logMessage(errorTypeString, replyUrl);
@@ -1146,7 +1258,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
         return;
 
     case 403:
-        errorTypeString = tr("Forbidden", "HTTP 403 error string")
+        errorTypeString = httpErrorString
+                        + tr("Forbidden", "HTTP 403 error string")
                         + " (403) " + replyFirstLine;
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
         emit logMessage(errorTypeString, replyUrl);
@@ -1155,7 +1268,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
         return;
 
     case 401:
-        errorTypeString = tr("Unauthorized", "HTTP 401 error string")
+        errorTypeString = httpErrorString
+                        + tr("Unauthorized", "HTTP 401 error string")
                         + " (401) " + replyFirstLine;
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
         emit logMessage(errorTypeString, replyUrl);
@@ -1165,7 +1279,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
     case 400:
-        errorTypeString = tr("Bad Request", "HTTP 400 error string")
+        errorTypeString = httpErrorString
+                        + tr("Bad Request", "HTTP 400 error string")
                         + " (400) " + replyFirstLine;
 
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
@@ -1183,7 +1298,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
         return;
 
     case 302:
-        errorTypeString = tr("Moved Temporarily", "HTTP 302 error string")
+        errorTypeString = httpErrorString
+                        + tr("Moved Temporarily", "HTTP 302 error string")
                         + " (302)";
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
         emit logMessage(errorTypeString, replyUrl);
@@ -1192,7 +1308,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
         return;
 
     case 301:
-        errorTypeString = tr("Moved Permanently", "HTTP 301 error string")
+        errorTypeString = httpErrorString
+                        + tr("Moved Permanently", "HTTP 301 error string")
                         + " (301)";
         emit currentJobChanged(errorTypeString + ": " + replyUrl);
         emit logMessage(errorTypeString, replyUrl);
@@ -1352,24 +1469,28 @@ void PumpController::requestFinished(QNetworkReply *reply)
             if (requestType == MainTimelineRequest)
             {
                 qDebug() << "It was the main timeline";
+                this->haveMainTL = true;
                 emit mainTimelineReceived(jsonDataList, this->postsPerPageMain,
                                           previousLink, nextLink);
             }
             else if (requestType == DirectTimelineRequest)
             {
                 qDebug() << "It was the direct messages timeline";
+                this->haveDirectTL = true;
                 emit directTimelineReceived(jsonDataList, this->postsPerPageOther,
                                             previousLink, nextLink);
             }
             else if (requestType == ActivityTimelineRequest)
             {
                 qDebug() << "It was the own activity timeline";
+                this->haveActivityTL = true;
                 emit activityTimelineReceived(jsonDataList, this->postsPerPageOther,
                                               previousLink, nextLink);
             }
             else if (requestType == FavoritesTimelineRequest)
             {
                 qDebug() << "It was the favorites timeline";
+                this->haveFavoritesTL = true;
                 emit favoritesTimelineReceived(jsonDataList, this->postsPerPageOther,
                                                previousLink, nextLink);
             }
@@ -1556,12 +1677,16 @@ void PumpController::requestFinished(QNetworkReply *reply)
         if (jsonParsedOK && jsonData.size() > 0)
         {
             qDebug() << "JSON parsed OK";
+            this->haveMinorFeed = true;
             emit currentJobChanged(tr("Minor feed received."));
 
             jsonDataList = jsonData["items"].toList();
             qDebug() << "Number of items in minor feed:" << jsonDataList.size();
 
-            emit minorFeedReceived(jsonDataList);
+            QString previousLink = jsonData["links"].toMap().value("prev").toMap().value("href").toString();
+            QString nextLink = jsonData["links"].toMap().value("next").toMap().value("href").toString();
+
+            emit minorFeedReceived(jsonDataList, previousLink, nextLink);
         }
         else
         {
@@ -1635,11 +1760,15 @@ void PumpController::requestFinished(QNetworkReply *reply)
                     if (totalReceivedFollowing >= this->userFollowingCount)
                     {
                         this->haveFollowing = true;
-                        emit currentJobChanged(tr("List of 'following' completely received."));
+                        const QString followingOkString = tr("List of 'following' "
+                                                             "completely received.");
+                        emit currentJobChanged(followingOkString);
+                        emit logMessage(followingOkString);
                     }
                     else
                     {
-                        emit currentJobChanged(tr("Partial list of 'following' received."));
+                        emit currentJobChanged(tr("Partial list of 'following' "
+                                                  "received."));
                     }
                 }
                 else // == FollowersListRequest
@@ -1653,11 +1782,15 @@ void PumpController::requestFinished(QNetworkReply *reply)
                     if (totalReceivedFollowers >= this->userFollowersCount)
                     {
                         this->haveFollowers = true;
-                        emit currentJobChanged(tr("List of 'followers' completely received."));
+                        const QString followersOkString = tr("List of 'followers' "
+                                                             "completely received.");
+                        emit currentJobChanged(followersOkString);
+                        emit logMessage(followersOkString);
                     }
                     else
                     {
-                        emit currentJobChanged(tr("Partial list of 'followers' received."));
+                        emit currentJobChanged(tr("Partial list of 'followers' "
+                                                  "received."));
                     }
                 }
             }
@@ -1712,7 +1845,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
     case CreatePersonListRequest:
         emit currentJobChanged(tr("Person list created successfully."));
 
-        this->getListsList(); // And reload the person lists
+        this->getListsList(); // And reload the person lists (FIXME!)
         break;
 
 
@@ -1720,7 +1853,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
     case DeletePersonListRequest:
         emit currentJobChanged(tr("Person list deleted successfully."));
 
-        this->getListsList(); // And reload the person lists
+        this->getListsList(); // And reload the person lists (FIXME!)
         break;
 
 
@@ -1978,7 +2111,16 @@ void PumpController::getToken()
         {
             qDebug() << "Warning, HMAC-SHA1 doesn't seem to be supported!";
 
-            // TMPFIX notify the user properly, etc.
+            // Notify the user about missing plugin
+            emit authorizationFailed(tr("OAuth support error"),
+                                     tr("Your installation of QOAuth, a library "
+                                        "used by Dianara, doesn't seem to have "
+                                        "HMAC-SHA1 support.")
+                                     + "\n"
+                                     + tr("You probably need to install the OpenSSL "
+                                          "plugin for QCA: %1, %2 or similar.")
+                                       .arg("qca2-plugin-openssl")
+                                       .arg("libqca2-plugin-ossl"));
         }
 
         qoauth->setConsumerKey(this->clientID.toLocal8Bit());
@@ -1989,17 +2131,14 @@ void PumpController::getToken()
         qDebug() << "GET: " << requestTokenURL
                  << "with" << qoauth->consumerKey() << qoauth->consumerSecret();
 
-
         QOAuth::ParamMap oAuthParams;
         oAuthParams.insert("oauth_callback", "oob");
 
-
         QOAuth::ParamMap reply = qoauth->requestToken(requestTokenURL,
                                                       QOAuth::GET,
-                                                      QOAuth::HMAC_SHA1,   // or PLAINTEXT?
+                                                      QOAuth::HMAC_SHA1,
                                                       oAuthParams);
 
-
         if (qoauth->error() == QOAuth::NoError)
         {
             qDebug() << "requestToken OK:" << reply.keys();
@@ -2029,10 +2168,14 @@ void PumpController::getToken()
         else
         {
             qDebug() << "QOAuth error" << qoauth->error() << "!";
-
             qDebug() << reply.keys();
-        }
 
+            emit authorizationFailed(tr("Authorization error"),
+                                     tr("There was an OAuth error while trying "
+                                        "to get the authorization token.")
+                                     + "\n\n"
+                                     + tr("QOAuth error %1").arg(qoauth->error()));
+        }
     }
 }
 
@@ -2093,6 +2236,13 @@ void PumpController::getInitialData()
 
     initialDataTimer->setInterval(3000);  // Every 3 sec
 
+    // If we're still waiting for a proxy password, don't do anything
+    if (this->needsProxyPassword())
+    {
+        emit currentJobChanged(tr("Waiting for proxy password..."));
+        return;
+    }
+
     /*
      * FIXME: this needs to be way more elaborate.
      *
@@ -2104,57 +2254,131 @@ void PumpController::getInitialData()
      *
      */
 
+    /* // TMP, tests for getMinorFeedProper()
+    this->getMinorFeed();
+    initialDataTimer->stop();
+    return;
+    */
+
     switch (this->initialDataStep)
     {
     case 0:
-        this->getUserProfile(this->userId);
+        if (!haveProfile)
+        {
+            this->getUserProfile(this->userId);
+        }
         break;
 
     case 1:
-        this->getContactList("following");
+        if (!haveFollowing && haveProfile)
+        {
+            this->getContactList("following");
+        }
         break;
 
     case 2:
-        this->getContactList("followers");
+        if (!haveFollowers && haveProfile)
+        {
+            this->getContactList("followers");
+        }
         break;
 
     case 3:
-        // Nothing, just extra time to get 'following' before timelines
+        // Just some extra time to get 'following' before timelines
         break;
 
     case 4:
-        this->getMainTimeline(0);
+        if (!haveMainTL)
+        {
+            this->getMainTimeline(0);
+        }
         break;
 
     case 5:
-        this->getMinorFeed();
+        if (!haveMinorFeed)
+        {
+            this->getMinorFeed();
+        }
         break;
 
     case 6:
-        this->getListsList();
+        if (!havePersonLists)
+        {
+            this->getListsList();
+        }
         break;
 
     case 7:
-        this->getDirectTimeline(0);
+        if (!haveDirectTL)
+        {
+            this->getDirectTimeline(0);
+        }
         break;
 
     case 8:
-        this->getActivityTimeline(0);
+        if (!haveActivityTL)
+        {
+            this->getActivityTimeline(0);
+        }
         break;
 
     case 9:
-        this->getFavoritesTimeline(0);
+        if (!haveFavoritesTL)
+        {
+            this->getFavoritesTimeline(0);
+        }
         break;
 
     case 10:
-        // Do nothing, so it takes longer for the final (default) step to arrive
+        // If some data is still missing, go back to the beginning of the cycle
+        if (!haveProfile || !haveFollowing || !haveFollowers
+         || !havePersonLists || !haveMainTL || !haveMinorFeed
+         || !haveDirectTL || !haveActivityTL || !haveFavoritesTL)
+        {
+            // Unless we've already tried several times, like people with broken
+            // contact lists, for instance, which will never be received
+            if (initialDataAttempts < 5)
+            {
+                initialDataStep = -1;
+                ++initialDataAttempts;
+                const QString restartString = tr("Some initial data was not "
+                                                 "received. Restarting "
+                                                 "initialization.");
+                emit currentJobChanged(restartString);
+                emit logMessage(restartString);
+            }
+            else
+            {
+                const QString giveUpString = tr("Some initial data was not "
+                                                "received after several "
+                                                "attempts. Something might "
+                                                "be wrong with your server. "
+                                                "You might still be able to "
+                                                "use the service normally.");
+                emit currentJobChanged(giveUpString);
+                emit logMessage(giveUpString);
+            }
+        }
+        else
+        {
+            const QString completeString = tr("All initial data received. "
+                                              "Initialization complete.");
+            emit currentJobChanged(completeString);
+            emit logMessage(completeString);
+
+            // If there are no problems, this will just wait one interal,
+            // so it takes longer for the final (default) step to arrive
+        }
         break;
 
 
     default:
-        emit currentJobChanged(tr("Ready."));
         initialDataTimer->stop();
 
+        const QString readyString = tr("Ready.");
+        emit currentJobChanged(readyString);
+        emit logMessage(readyString);
+
         qDebug() << "--------------------------------------";
         qDebug() << "-- All initial data loaded -----------";
         qDebug() << "--------------------------------------";
@@ -2328,7 +2552,8 @@ void PumpController::postAvatarStepTwo(QString id)
 
         QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
 
-        QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST, PublishAvatarRequest);
+        QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
+                                                           PublishAvatarRequest);
 
 
         QVariantMap jsonVariantObject;
