@@ -32,6 +32,7 @@
 #include <QNetworkReply>
 #include <QNetworkAccessManager>
 #include <QSslError> // TMP
+#include <QNetworkProxy>
 #include <QTimer>
 #include <QFile>
 
@@ -62,6 +63,13 @@ public:
     explicit PumpController(QObject *parent = 0);
     ~PumpController();
 
+    void setProxyConfig(QNetworkProxy::ProxyType proxyType,
+                        QString hostname, int port,
+                        bool useAuth,
+                        QString user, QString password);
+    bool needsProxyPassword();
+    void setProxyPassword(QString password);
+
     void setPostsPerPageMain(int ppp);
     void setPostsPerPageOther(int ppp);
 
@@ -107,11 +115,12 @@ public:
 
     void getTimeline(int timelineType, QString url);
 
-    void getPostLikes(QString postLikesURL);
-    void getPostComments(QString postCommentsURL);
-    void getPostShares(QString postSharesURL);
+    void getPostLikes(QString postLikesUrl);
+    void getPostComments(QString postCommentsUrl);
+    void getPostShares(QString postSharesUrl);
 
     void getMinorFeed(int offset = 0);
+    void getMinorFeedProper(QString url = "");
 
     QNetworkRequest prepareRequest(QString url,
                                    QOAuth::HttpMethod method,
@@ -185,6 +194,7 @@ public:
 
 signals:
     void openingAuthorizeURL(QUrl url);
+    void authorizationFailed(QString errorTitle, QString errorMessage);
     void authorizationStatusChanged(bool authorized);
 
     void profileReceived(QString avatarURL, QString fullName,
@@ -213,7 +223,8 @@ signals:
     void likesReceived(QVariantList likesList, QString originatingPostURL);
     void commentsReceived(QVariantList commentsList, QString originatingPostURL);
 
-    void minorFeedReceived(QVariantList activitiesList);
+    void minorFeedReceived(QVariantList activitiesList,
+                           QString previousLink, QString nextLink);
 
     void avatarPictureReceived(QByteArray pictureData, QUrl pictureURL);
     void imageReceived(QByteArray pictureData, QUrl pictureURL);
@@ -294,6 +305,8 @@ private:
     QString userName;
     QString serverURL;
 
+    bool proxyUsesAuth;
+
     QString userFollowersURL;
     int userFollowersCount;
     int userFollowingCount;
@@ -303,10 +316,16 @@ private:
 
     QTimer *initialDataTimer;
     int initialDataStep;
+    int initialDataAttempts;
     bool haveProfile;
     bool haveFollowing;
     bool haveFollowers;
     bool havePersonLists;
+    bool haveMainTL;
+    bool haveDirectTL;
+    bool haveActivityTL;
+    bool haveFavoritesTL;
+    bool haveMinorFeed;
 
 
     int postsPerPageMain;
