@@ -29,9 +29,9 @@ TimeLine::TimeLine(int timelineType,
     this->pController = pumpController;
     this->fChecker = filterChecker;
 
-    // Set 5 empty colors initially
-    this->highlightColorsList << "" << "" << "" << "" << "";
-    // They will be set later, but the string list needs to have all 5 elements
+    // Set 6 empty colors initially
+    this->highlightColorsList << "" << "" << "" << "" << "" << "";
+    // They will be set later, but the string list needs to have all 6 elements
     // before the demo posts are created
 
 
@@ -50,6 +50,7 @@ TimeLine::TimeLine(int timelineType,
 
     QVariantMap demoObjectData;
     demoObjectData.insert("published",   "2013-05-01T00:00:00Z");
+    demoObjectData.insert("objectType",  "note");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -60,42 +61,46 @@ TimeLine::TimeLine(int timelineType,
     {
     case TimelineTypeMain:
         demoObjectData.insert("displayName", tr("Welcome to Dianara"));
-        demoObjectData.insert("content",     tr("Dianara is a <b>pump.io</b> client.")
-                                             + "<br>"
+        demoObjectData.insert("content",
+                              tr("Dianara is a <b>pump.io</b> client.")
+                              + "<br>"
 
-                                      + tr("If you don't have a Pump account yet, you can get one "
-                                           "at the following address:")
-                                      + "<br>"
-                                        "<a href=\"http://pump.io/tryit.html\">http://pump.io/tryit.html</a>"
-                                        "<br><br>"
+                              + tr("If you don't have a Pump account yet, you can get one "
+                                   "at the following address, for instance:")
+                              + "<br>"
+                                "<a href=\"http://pump.io/tryit.html\">http://pump.io/tryit.html</a>"
+                                "<br><br>"
 
-                                      + tr("First, configure your account from the "
-                                           "<b>Settings - Account</b> menu.")
-                                      + "<br>"
-                                      + tr("After the process is done, your profile "
-                                           "and timelines should update automatically.")
-                                      + "<br><br>"
+                              + tr("Press <b>F1</b> if you want to open the Help window.")
+                              + "<br><br>"
 
-                                      + tr("Take a moment to look around the menus and "
-                                           "the Configuration window.")
-                                      + "<br><br>"
+                              + tr("First, configure your account from the "
+                                   "<b>Settings - Account</b> menu.")
+                              + " "
+                              + tr("After the process is done, your profile "
+                                   "and timelines should update automatically.")
+                              + "<br><br>"
 
-                                      + tr("You can also set your profile data and picture from "
-                                           "the <b>Settings - Edit Profile</b> menu.")
-                                      + "<br><br>"
+                              + tr("Take a moment to look around the menus and "
+                                   "the Configuration window.")
+                              + "<br><br>"
 
-                                      + tr("There are tooltips everywhere, so if you hover "
-                                           "a button or a text field with your mouse, you'll "
-                                           "probably see some extra information.")
-                                      + "<br><br>"
+                              + tr("You can also set your profile data and picture from "
+                                   "the <b>Settings - Edit Profile</b> menu.")
+                              + "<br><br>"
 
-                                      + "<a href=\"http://jancoding.wordpress.com/dianara\">"
-                                      + tr("Dianara's blog") + "</a><br><br>"
+                              + tr("There are tooltips everywhere, so if you "
+                                   "hover over a button or a text field with "
+                                   "your mouse, you'll probably see some "
+                                   "extra information.")
+                              + "<br><br>"
 
-                                        "<a href=\"https://github.com/e14n/pump.io/wiki/FAQ\">"
-                                      + tr("Frequently asked questions about pump.io")
-                                      + "</a>"
-                                      + "<br><br>");
+                              + "<a href=\"http://jancoding.wordpress.com/dianara\">"
+                              + tr("Dianara's blog") + "</a><br><br>"
+                                "<a href=\"https://github.com/e14n/pump.io/wiki/FAQ\">"
+                              + tr("Frequently asked questions about Pump.io")
+                              + "</a>"
+                              + "<br><br>");
 
         this->previousNewestPostId = settings.value("previousNewestPostIdMain", "").toString();
         break;
@@ -103,7 +108,8 @@ TimeLine::TimeLine(int timelineType,
 
     case TimelineTypeDirect:
         demoObjectData.insert("displayName",  tr("Direct Messages Timeline"));
-        demoObjectData.insert("content",      tr("Here, you'll see posts specifically directed to you.")
+        demoObjectData.insert("content",      tr("Here, you'll see posts "
+                                                 "specifically directed to you.")
                                               + "<br><br>");
         this->previousNewestPostId = settings.value("previousNewestPostIdDirect", "").toString();
         break;
@@ -225,6 +231,18 @@ TimeLine::TimeLine(int timelineType,
             this, SLOT(scrollToBottom()));
     this->addAction(scrollBottomAction);
 
+    // Previous/Next page in timeline
+    previousPageAction = new QAction(this);
+    previousPageAction->setShortcut(QKeySequence("Ctrl+Left"));
+    connect(previousPageAction, SIGNAL(triggered()),
+            this, SLOT(goToPreviousPage()));
+    this->addAction(previousPageAction);
+
+    nextPageAction = new QAction(this);
+    nextPageAction->setShortcut(QKeySequence("Ctrl+Right"));
+    connect(nextPageAction, SIGNAL(triggered()),
+            this, SLOT(goToNextPage()));
+    this->addAction(nextPageAction);
 
 
     // Add the default "demo" post
